@@ -23,6 +23,7 @@
 #include "../src/kdeapplicationtreelistwidget.h"
 #include <qlistwidget.h>
 #include <qpushbutton.h>
+#include <QHeaderView>
 #include <qtest.h>
 #include <KTreeWidgetSearchLine>
 
@@ -40,12 +41,16 @@ void KDEApplicationDebugSettingPageTest::shouldHaveDefaultValue()
     KDEApplicationDebugSettingPage page;
     KDEApplicationTreeListWidget *listWidget = page.findChild<KDEApplicationTreeListWidget *>(QStringLiteral("listwidget"));
     QVERIFY(listWidget);
+    QVERIFY(!listWidget->rootIsDecorated());
+    QVERIFY(listWidget->header()->isHidden());
+    QVERIFY(listWidget->isColumnHidden(2));
+    QCOMPARE(listWidget->columnCount(), 4);
 
     QPushButton *selectAll = page.findChild<QPushButton *>(QStringLiteral("selectall"));
     QVERIFY(selectAll);
     QVERIFY(selectAll->isEnabled());
 
-    QPushButton *deselectAll = page.findChild<QPushButton *>(QStringLiteral("deselectall"));   
+    QPushButton *deselectAll = page.findChild<QPushButton *>(QStringLiteral("deselectall"));
     QVERIFY(deselectAll);
     QVERIFY(deselectAll->isEnabled());
 
@@ -53,7 +58,6 @@ void KDEApplicationDebugSettingPageTest::shouldHaveDefaultValue()
     QVERIFY(mTurnOffAllMessages);
     QVERIFY(mTurnOffAllMessages->isEnabled());
 
-
     KTreeWidgetSearchLine *searchLine = page.findChild<KTreeWidgetSearchLine *>(QStringLiteral("searchline"));
     QVERIFY(searchLine);
     QVERIFY(searchLine->text().isEmpty());
